=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2006-02-16 16:43:07 +0000
+++ bzrlib/builtins.py	2006-02-16 17:09:09 +0000
@@ -2207,3 +2207,4 @@
 # we do need to load at least some information about them to know of 
 # aliases.
 from bzrlib.conflicts import cmd_resolve, cmd_conflicts, restore
+from bzrlib.sign_my_commits import cmd_sign_my_commits

=== added file 'bzrlib/sign_my_commits.py'
--- bzrlib/sign_my_commits.py	1970-01-01 00:00:00 +0000
+++ bzrlib/sign_my_commits.py	2006-02-15 15:42:09 +0000
@@ -0,0 +1,80 @@
+# Copyright (C) 2005 Canonical Ltd
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+"""Command which looks for unsigned commits by the current user, and signs them.
+"""
+
+from bzrlib.commands import Command
+import bzrlib.config
+import bzrlib.errors as errors
+import bzrlib.gpg
+from bzrlib.option import Option
+
+
+class cmd_sign_my_commits(Command):
+    """Sign all commits by a given committer.
+
+    If location is not specified the local tree is used.
+    If committer is not specified the default committer is used.
+
+    This does not sign commits that already have signatures.
+    """
+
+    takes_options = [Option('dry-run'
+                            , help='Don\'t actually sign anything, just print'
+                                   ' the revisions that would be signed')
+                    ]
+    takes_args = ['location?', 'committer?']
+
+    def run(self, location=None, committer=None, dry_run=False):
+        if location is None:
+            from bzrlib.workingtree import WorkingTree
+            # Open the containing directory
+            wt = WorkingTree.open_containing('.')[0]
+            b = wt.branch
+        else:
+            # Passed in locations should be exact
+            from bzrlib.branch import Branch
+            b = Branch.open(location)
+        repo = getattr(b, 'repository', b)
+
+        config = bzrlib.config.BranchConfig(b)
+
+        if committer is None:
+            committer = config.username()
+
+        gpg_strategy = bzrlib.gpg.GPGStrategy(config)
+
+        if not repo.revision_store.listable():
+            raise errors.BzrCommandError('cannot sign revisions on non-listable transports')
+
+        count = 0
+        for rev_id in repo.revision_store:
+            if repo.revision_store.has_id(rev_id, suffix='sig'):
+                continue
+            
+            rev = repo.get_revision(rev_id)
+            if rev.committer != committer:
+                continue
+
+            # We have a revision without a signature who has a 
+            # matching committer, start signing
+            print rev_id
+            count += 1
+            if not dry_run:
+                repo.sign_revision(rev_id, gpg_strategy)
+        print 'Signed %d revisions' % (count,)
+
+

=== modified file 'bzrlib/tests/blackbox/__init__.py'
--- bzrlib/tests/blackbox/__init__.py	2006-02-16 16:43:07 +0000
+++ bzrlib/tests/blackbox/__init__.py	2006-02-16 17:09:09 +0000
@@ -50,6 +50,7 @@
                      'bzrlib.tests.blackbox.test_revno',
                      'bzrlib.tests.blackbox.test_revision_info',
                      'bzrlib.tests.blackbox.test_selftest',
+                     'bzrlib.tests.blackbox.test_sign_my_commits',
                      'bzrlib.tests.blackbox.test_status',
                      'bzrlib.tests.blackbox.test_too_much',
                      'bzrlib.tests.blackbox.test_update',

=== modified file 'bzrlib/tests/blackbox/test_re_sign.py'
--- bzrlib/tests/blackbox/test_re_sign.py	2006-02-14 17:01:48 +0000
+++ bzrlib/tests/blackbox/test_re_sign.py	2006-02-15 15:33:29 +0000
@@ -16,7 +16,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-"""Black-box tests for bzr cat.
+"""Black-box tests for bzr re-sign.
 """
 
 import os

=== added file 'bzrlib/tests/blackbox/test_sign_my_commits.py'
--- bzrlib/tests/blackbox/test_sign_my_commits.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/blackbox/test_sign_my_commits.py	2006-02-15 15:42:09 +0000
@@ -0,0 +1,119 @@
+# Copyright (C) 2005 by Canonical Ltd
+# -*- coding: utf-8 -*-
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+
+"""Black-box tests for bzr sign-my-commits.
+"""
+
+import os
+
+import bzrlib.gpg
+from bzrlib.testament import Testament
+from bzrlib.tests import TestCaseInTempDir
+from bzrlib.workingtree import WorkingTree
+
+
+class SignMyCommits(TestCaseInTempDir):
+
+    def monkey_patch_gpg(self):
+        """Monkey patch the gpg signing strategy to be a loopback.
+
+        This also registers the cleanup, so that we will revert to
+        the original gpg strategy when done.
+        """
+        self._oldstrategy = bzrlib.gpg.GPGStrategy
+
+        # monkey patch gpg signing mechanism
+        bzrlib.gpg.GPGStrategy = bzrlib.gpg.LoopbackGPGStrategy
+
+        self.addCleanup(self._fix_gpg_strategy)
+
+    def _fix_gpg_strategy(self):
+        bzrlib.gpg.GPGStrategy = self._oldstrategy
+
+    def setup_tree(self):
+        wt = WorkingTree.create_standalone('.')
+        wt.commit("base A", allow_pointless=True, rev_id='A')
+        wt.commit("base B", allow_pointless=True, rev_id='B')
+        wt.commit("base C", allow_pointless=True, rev_id='C')
+        wt.commit("base D", allow_pointless=True, rev_id='D',
+                committer='Alternate <alt@foo.com>')
+
+        return wt
+
+    def test_sign_my_commits(self):
+        #Test re signing of data.
+        wt = self.setup_tree()
+        repo = wt.branch.repository
+
+        self.monkey_patch_gpg()
+
+        self.assertFalse(repo.revision_store.has_id('A', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('B', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('C', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('D', 'sig'))
+
+        self.run_bzr('sign-my-commits')
+
+        self.assertTrue(repo.revision_store.has_id('A', 'sig'))
+        self.assertTrue(repo.revision_store.has_id('B', 'sig'))
+        self.assertTrue(repo.revision_store.has_id('C', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('D', 'sig'))
+            
+    def test_sign_my_commits_location(self):
+        os.mkdir('other')
+        os.chdir('other')
+        wt = self.setup_tree()
+        repo = wt.branch.repository
+        os.chdir('..')
+
+        self.monkey_patch_gpg()
+
+        self.run_bzr('sign-my-commits', 'other')
+
+        self.assertTrue(repo.revision_store.has_id('A', 'sig'))
+        self.assertTrue(repo.revision_store.has_id('B', 'sig'))
+        self.assertTrue(repo.revision_store.has_id('C', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('D', 'sig'))
+
+    def test_sign_diff_committer(self):
+        wt = self.setup_tree()
+        repo = wt.branch.repository
+
+        self.monkey_patch_gpg()
+
+        self.run_bzr('sign-my-commits', '.', 'Alternate <alt@foo.com>')
+
+        self.assertFalse(repo.revision_store.has_id('A', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('B', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('C', 'sig'))
+        self.assertTrue(repo.revision_store.has_id('D', 'sig'))
+
+    def test_sign_dry_run(self):
+        wt = self.setup_tree()
+        repo = wt.branch.repository
+
+        self.monkey_patch_gpg()
+
+        out = self.run_bzr('sign-my-commits', '--dry-run')[0]
+
+        self.assertEquals('A\nB\nC\nSigned 3 revisions\n', out)
+        self.assertFalse(repo.revision_store.has_id('A', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('B', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('C', 'sig'))
+        self.assertFalse(repo.revision_store.has_id('D', 'sig'))
+

